==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/kernel/src/com/caucho/env/actor/ActorQueueBuilder.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.env.actor;

/**
 * Interface for an actor queue
 */
public class ActorQueueBuilder<T> extends AbstractActorQueueBuilder<T>
{
  public ActorQueueApi<T> build()
  {
    validateFullBuilder();
    
    return build(getProcessors());
  }
  
  public ActorQueueApi<T> build(ActorProcessor<? super T> ...processors)
  {
    validateBuilder();
    
    if (processors.length == 1) {
      return new ValueActorQueue<T>(getCapacity(), processors);
    }
    else {
      return new MultiworkerActorQueue<T>(getCapacity(), 
                                          getMultiworkerOffset(),
                                          processors);
    }
  }
}

==> resin-4.0.55-src.tar.gz: resin-4.0.55/modules/kernel/src/com/caucho/env/actor/ActorQueueBuilder.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.env.actor;

import com.caucho.env.actor2.ActorQueue2;
import com.caucho.env.actor2.ActorQueue2MultiWorker;

/**
 * Interface for an actor queue
 */
public class ActorQueueBuilder<T> extends AbstractActorQueueBuilder<T>
{
  public ActorQueueApi<T> build()
  {
    validateFullBuilder();
    
    return build(getProcessors());
  }
  
  public ActorQueueApi<T> build(ActorProcessor<? super T> ...processors)
  {
    validateBuilder();
    
    if (processors.length == 1) {
      //return new ValueActorQueue<T>(getCapacity(), processors);
      return new ActorQueue2<T>(getCapacity(), processors[0]);
    }
    else {
      /*
      return new MultiworkerActorQueue<T>(getCapacity(), 
                                          getMultiworkerOffset(),
                                          processors);
                                          */
      return new ActorQueue2MultiWorker<T>(getCapacity(), 
          getMultiworkerOffset(),
          processors);
    }
  }
}
